# ontoRunNER

This repository is a wrapper project around the following named entity recognition (NER) tools:
 - [OGER](https://github.com/OntoGene/OGER).
 - [spaCy](https://spacy.io)
   - using [sciSpaCy](https://scispacy.apps.allenai.org) pipeline 
   namely the CRAFT corpus (`en_ner_craft_md`) used by default. Others can be used as listed [here](https://github.com/allenai/scispacy#available-models)

## Documentation

[ontoRunNER using Sphinx](https://monarch-initiative.github.io/ontorunner/index.html)
